# Pie - Powerful control version

![BADGE](https://img.shields.io/static/v1?label=status&message=stable&color=green)
![BADGE](https://img.shields.io/static/v1?label=license&message=GPL%20v3.0&color=blue)

A version control **written in Python** designed to be simple and complete, with many features. An ***improved version*** of [Vestory](https://github.com/jaedsonpys/vestory). With it, you can:

- Create repositories;
- Tracking files;
- Ignore files with `.ignore` file;
- Get status of files;
- Commit of tracked files;
- Get all commits log;
- Merge all changes to the committed files;
- Get the changed lines between files.

To learn how to use `Pie`, see the [full documentation here](https://github.com/jaedsonpys/pie/tree/master/DOCS). Download `Pie` using the pip package manager:

```
pip install pie-cli
```

## License

This project uses the `GNU GPL v3.0` license, [see the license file](https://github.com/jaedsonpys/pie/blob/master/LICENSE) for **more information**.
